---
title: 查询聊天室房间信息
---

# 查询聊天室房间信息

获取聊天室的信息，可返回以下数据：

- 聊天室成员总数
- 指定数量（最多 20 个）的聊天室成员的列表，包括该成员的用户 ID 以及加入聊天室的时间

:::tip

 **频率限制**：单个设备每秒钟支持调用一次，每分钟单个设备最多调用 20 次。
:::


您可以使用下面方法：

```ts
    let roomId = this.chatroomId;

    let option: ICountOption = {
      count: 10,
      order: Order.Descending
    }

    IMEngine.getInstance().getChatroomInfo(roomId, option).then(result => {
      if (EngineError.Success !== result.code) {
        // 获取聊天室信息失败
        return;
      }
      if (!result.data) {
        // 聊天室信息为空
        return;
      }
      let chatroomInfo = result.data as ChatroomInfo;
    });
```

```ts
/**
 * 聊天室信息
 * @version 1.0.0
 */
class ChatroomInfo {
  /**
   * 聊天室 ID
   */
  roomId: string = "";
  /**
   * 当前聊天室的成员总数
   */
  totalUserCount: number = 0;
  /**
   * 排序
   */
  order: Order = Order.Ascending;
  /**
   * 聊天室中的部分成员信息列表
   *
   * order 为 Ascending 返回最早加入的成员列表，按成员加入时间升序排列
   *
   * order 为 Descending 返回最晚加入的成员列表，按成员加入时间降序排列
   */
  userInfoList: List<ChatroomMemberInfo> = new List();
}
```


[ChatRoomInfo]: https://doc.rongcloud.cn/apidoc/chatroom-android/latest/zh_CN/html/-android--chatroom--s-d-k/io.rong.imlib.model/-chat-room-info/index.html
[ChatRoomMemberOrder]: https://doc.rongcloud.cn/apidoc/chatroom-android/latest/zh_CN/html/-android--chatroom--s-d-k/io.rong.imlib.model/-chat-room-info/-chat-room-member-order/index.html
[ChatRoomMemberInfo]: https://doc.rongcloud.cn/apidoc/chatroom-android/latest/zh_CN/html/-android--chatroom--s-d-k/io.rong.imlib.model/-chat-room-member-info/index.html
[getChatRoomInfo]: https://doc.rongcloud.cn/apidoc/chatroom-android/latest/zh_CN/html/-android--chatroom--s-d-k/io.rong.imlib.chatroom.base/-rong-chat-room-client/get-chat-room-info.html

